@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * Copyright (C) 2014 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,18 +30,17 @@
 #include <QTextDocument>
 
 CalendarIndexer::CalendarIndexer(const QString &path)
-    : AbstractIndexer(), m_db(0)
+    : AbstractIndexer(), m_db(nullptr)
 {
     try {
         m_db = new Akonadi::Search::XapianDatabase(path, true);
-    }
-    catch (const Xapian::DatabaseCorruptError &err) {
+    } catch (const Xapian::DatabaseCorruptError &err) {
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Database Corrupted - What did you do?";
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << err.get_error_string();
-        m_db = 0;
+        m_db = nullptr;
     } catch (const Xapian::Error &e) {
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
-        m_db = 0;
+        m_db = nullptr;
     }
 }
 
