@@ -17,7 +17,7 @@
  *
  */
 
-#include "helper_p.h"
+
 #include "xapiandatabase.h"
 #include "xapiandocument.h"
 
@@ -27,11 +27,11 @@
 
 #if defined(HAVE_MALLOC_H)
 #include <malloc.h>
-#include <unistd.h>
-#else
-#include <unistd.h>
 #endif
 
+#include <chrono>
+#include <thread>
+
 using namespace Akonadi::Search;
 
 XapianDatabase::XapianDatabase(const QString &path, bool writeOnly)
@@ -176,9 +176,9 @@ Xapian::WritableDatabase XapianDatabase::createWritableDb()
             Xapian::WritableDatabase wdb(m_path, Xapian::DB_CREATE_OR_OPEN);
             return wdb;
         } catch (const Xapian::DatabaseLockError &) {
-            usleep(i * 50 * 1000);
+            std::this_thread::sleep_for(std::chrono::milliseconds(i * 50));
         } catch (const Xapian::DatabaseModifiedError &) {
-            usleep(i * 50 * 1000);
+            std::this_thread::sleep_for(std::chrono::milliseconds(i * 50));
         } catch (const Xapian::DatabaseCreateError &err) {
             qCDebug(AKONADI_SEARCH_XAPIAN_LOG) << err.get_error_string();
             return Xapian::WritableDatabase();
